/*#############################################################
File Name       : ex1_flash_one_led.c
Author          : Grant Phillips
Date Modified   : 15/09/2015
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F429I-Discovery

Description     : Example program that turns on an LED for 
                  400ms, then off for 400ms, repeatedly.        

Requirements    : * STM32F429I-Discovery Board
									* Make sure the STM32F429I_Defaults.c file is 
										in the same folder than the project
              
Circuit         : * The on-board USER GREEN LED connected to PG13

See the STM32F429I-Discovery User Manual (UM1670) for the block 
diagram of the STM32F429ZIT6 processor (p11), a summary of the 
GPIO connections and free IO pins (p19-25) and the schematic 
diagram (p27-33).
##############################################################*/

#include "STM32F429I_Defaults.c"																//library for the defaults of a blank project in Keil uVision

int main(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
		
	/* GPIOG Periph clock enable */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOG, ENABLE);					//enable the AHB1 bus to use GPIOG
  
	/* Configure PG13 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_13;										//which pins to setup, seperated by |
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;									//setup for output mode
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;								//push-pull mode; also available is GPIO_OType_OD (open drain)
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;							//update speed is 50Mhz
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							//output not pulled up or down
  GPIO_Init(GPIOG, &GPIO_InitStructure);												//initialize GPIOG with the above structure
	
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	if (SysTick_Config(SystemCoreClock / 1000))
  { 
    while (1);																									//will end up in this infinite loop if there was an error with Systick_Config
  }
	
	/* Main program loop */
	while(1)
	{
		GPIO_WriteBit(GPIOG, GPIO_Pin_13, Bit_SET);									//set bit 13 on GPIOG
		Delay(400);																									//wait 400ms	
		GPIO_WriteBit(GPIOG, GPIO_Pin_13, Bit_RESET);								//clear bit 13 on GPIOG
		Delay(400);																									//wait 400ms	
	}
}
