/*#############################################################
File Name       : ex3_userbutton_led.c
Author          : Grant Phillips
Date Modified   : 15/09/2015
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F429I-Discovery

Description     : Reads the value of the on-board user button and 
									then turns an LED on when the button is on, 
									otherwise the LED is turned off.       

Requirements    : * STM32F429I-Discovery Board
									* Make sure the STM32F429I_Defaults.c file is 
										in the same folder than the project
              
Circuit         : * The on-board USER GREEN LED connected to PG13
									* The on-board USER pushbutton connected to PA0

See the STM32F429I-Discovery User Manual (UM1670) for the block 
diagram of the STM32F429ZIT6 processor (p11), a summary of the 
GPIO connections and free IO pins (p19-25) and the schematic 
diagram (p27-33).
##############################################################*/

#include "STM32F429I_Defaults.c"																//library for the defaults of a blank project in Keil uVision

void Init_LED_Button(void);																			//prototype for a user function to initialize the LED and Button
	
int main(void)
{
	uint8_t inval;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	if (SysTick_Config(SystemCoreClock / 1000))
  { 
    while (1);																									//will end up in this infinite loop if there was an error with Systick_Config
  }
	
	Init_LED_Button();																						//Initialize the LED and Button pins
	
	/* Main program loop */
	while(1)
	{
		/* Read the value on input pin PA0 */
		inval = GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0);	
		
		/* Write the input value to PG13 */
		/* according to the user manual on p32, when the user button is released, the input will be 0 
		and when pushed it will be 1, so no inversion required as in ex2_extbutton_led.c */
		if (inval == 1)												
			GPIO_SetBits(GPIOG, GPIO_Pin_13);		//PG13 = 1				
		else
			GPIO_ResetBits(GPIOG, GPIO_Pin_13);	//PG13 = 0																				
	}
}



void Init_LED_Button(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
		
	/* GPIOA and GPIOG Periph clock enable */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOA | RCC_AHB1Periph_GPIOG, ENABLE);					//enable the AHB1 bus to use GPIOG and GPIOA
  
	/* Configure PG13 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_13;										//which pins to setup, seperated by |
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;									//setup for output mode
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;								//push-pull mode; also available is GPIO_OType_OD (open drain)
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;							//update speed is 50Mhz
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							//output not pulled up or down
  GPIO_Init(GPIOG, &GPIO_InitStructure);												//initialize GPIOG with the above structure
	
	/* Configure PA0 in input mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;									//setup for input mode
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							//input not pulled up or down
  GPIO_Init(GPIOA, &GPIO_InitStructure);	
}
