/*#############################################################
File Name       : ex4_extinput_led.c
Author          : Grant Phillips
Date Modified   : 15/09/2015
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F429I-Discovery

Description     : Reads the value of an external input and 
									then turns an LED on when the input is on, 
									otherwise the LED is turned off. To prevent
									the input from "floating" between a 1 and 0
									when no input is connected, we pull the input
									up to 3V using the STM32F429I internal pullup
									resistors.  It would however be safer to do
									this pullup externally using a seperate resistor.

Requirements    : * STM32F429I-Discovery Board
									* Make sure the STM32F429I_Defaults.c file is 
										in the same folder than the project
              
Circuit         : * The on-board USER GREEN LED connected to PG13
									* An external input on PA5

See the STM32F429I-Discovery User Manual (UM1670) for the block 
diagram of the STM32F429ZIT6 processor (p11), a summary of the 
GPIO connections and free IO pins (p19-25) and the schematic 
diagram (p27-33).
##############################################################*/

#include "STM32F429I_Defaults.c"																//library for the defaults of a blank project in Keil uVision

void Init_IO(void);																							
	
int main(void)
{
	uint8_t inval;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	if (SysTick_Config(SystemCoreClock / 1000))
  { 
    while (1);																									//will end up in this infinite loop if there was an error with Systick_Config
  }
	
	Init_IO();																						
	
	/* Main program loop */
	while(1)
	{
		/* Read the value on input pin PA5 */
		inval = GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_5);	
		
		/* Write the input value to PG13 */
		if (inval == 1)												
			GPIO_SetBits(GPIOG, GPIO_Pin_13);		//PG13 = 1				
		else
			GPIO_ResetBits(GPIOG, GPIO_Pin_13);	//PG13 = 0																				
	}
}



void Init_IO(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
		
	/* GPIOA and GPIOG Periph clock enable */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOA | RCC_AHB1Periph_GPIOG, ENABLE);					//enable the AHB1 bus to use GPIOG and GPIOA
  
	/* Configure PG13 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_13;										//which pins to setup, seperated by |
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;									//setup for output mode
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;								//push-pull mode; also available is GPIO_OType_OD (open drain)
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;							//update speed is 50Mhz
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							//output not pulled up or down
  GPIO_Init(GPIOG, &GPIO_InitStructure);												//initialize GPIOG with the above structure
	
	/* Configure PA5 in input mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;									
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;									//enable internal Pullup resistors on the GPIO pins
  GPIO_Init(GPIOA, &GPIO_InitStructure);	
}
